@@ -332,8 +332,7 @@ class CAE_B3U4I:
             self.offset_miso + 8]
         power_l3 = (bB_update.updated[self.node][self.offset_miso + 9] << 8) + bB_update.updated[self.node][
             self.offset_miso + 10]
-        power = [200, 100, 50]
-        #power = [power_l1, power_l2, power_l3]
+        power = [power_l1, power_l2, power_l3]
         if self.brick_id == 4602:
             self.power = [i * self.pow_val_602 if i > self.filter_max or i < self.filter_min else 0 for i in np.int16(power)]
         else:
